@@ -18,10 +18,19 @@ jQuery(function() {
 
         // TODO: wrap long lines before quoting
         selection = selection.replace(/^/gm, "> ");
-        selection = selection.concat("\n\n");
+        if ( RT.Config.MessageBoxRichText ) {
+            selection = selection.replace(/\r?\n/g, "<br>");
+            selection = selection.concat("<br><br>");
+        }
+        else {
+            selection = selection.concat("\n\n");
+        }
         selection = encodeURIComponent(selection);
 
-        link.attr("href", link.attr("href").concat("&UpdateContent=" + selection));
+        if ( !link.prop('data-href') ) {
+            link.prop('data-href', link.attr('href'));
+        }
+        link.attr("href", link.prop("data-href").concat("&UpdateContent=" + selection));
     };
 
     var apply_quote = function() {
